Struct optimization::problems::Rosenbrock [] [src]

pub struct Rosenbrock { /* fields omitted */ }

Two-dimensional Rosenbrock function.

A non-convex function with its global minimum inside a long, narrow, parabolic shaped flat valley:

f(x, y) = (a - x)² + b (y - x²)²

Global minimum: f(a, a²) = 0

Methods

impl Rosenbrock
[src]

Creates a new Rosenbrock function given a and b, commonly definied with 1 and 100, respectively, which also corresponds to the default.