Trait optimization::Minimizer [] [src]

pub trait Minimizer<F: ?Sized> {
    type Solution: Evaluation;
    fn minimize(
        &self,
        function: &F,
        initial_position: Vec<f64>
    ) -> Self::Solution; }

Defines an optimizer that is able to minimize a given objective function F.

Associated Types

Type of the solution the Minimizer returns.

Required Methods

Performs the actual minimization and returns a solution that might be better than the initially provided one.

Implementors